pub struct AvellanedaStoikovBilateralHawkesOrderFlowImbalanceStrategy {
pub params: AvellanedaStoikovBilateralHawkesOrderFlowImbalanceParameters,
pub bid_spread_table: Arc<LookupTable>,
pub ask_spread_table: Arc<LookupTable>,
/* private fields */
}Expand description
Avellaneda-Stoikov strategy driven by precomputed FDM bilateral-Hawkes-with-OFI spreads.
On every tick the strategy:
- Reads
hawkes_buy_intensity(lambda+) andhawkes_sell_intensity(lambda-) fromobs.parameters. - Interpolates the 4-D FDM spread tables at
(q, lambda+, lambda-, tau). - Places bid/ask orders at
mid -/+ interpolated_spread.
The spreads embed the adverse-selection response to order flow imbalance, automatically skewing quotes when one side is more toxic than the other.
Table format
Both tables must be 4-dimensional with axes [q, lambda+, lambda-, tau]:
- axis 0: inventory grid (e.g. -10..10, 21 points)
- axis 1: buy-side intensity grid (e.g. 0.0..8.0, 40 points)
- axis 2: sell-side intensity grid (e.g. 0.0..8.0, 40 points)
- axis 3: time remaining in seconds (0.0..T_HORIZON)
Fields
params: AvellanedaStoikovBilateralHawkesOrderFlowImbalanceParametersbid_spread_table: Arc<LookupTable>4D lookup table for the bid half-spread: axes [q, lambda+, lambda-, tau].
ask_spread_table: Arc<LookupTable>4D lookup table for the ask half-spread: axes [q, lambda+, lambda-, tau].
Implementations
Sourceimpl AvellanedaStoikovBilateralHawkesOrderFlowImbalanceStrategy
impl AvellanedaStoikovBilateralHawkesOrderFlowImbalanceStrategy
pub fn new( params: AvellanedaStoikovBilateralHawkesOrderFlowImbalanceParameters, bid_spread_table: Arc<LookupTable>, ask_spread_table: Arc<LookupTable>, ) -> Self